@@ -98,50 +98,6 @@ extern const char *netatom_names[];
 /** atoms */
 extern xcb_atom_t netatoms[NUM_NETATOMS];
 
-/**
- * Structure describing a workarea/monitor.
- */
-typedef struct _workarea {
-  /** numeric monitor id. */
-  int monitor_id;
-  /** if monitor is set as primary monitor. */
-  int primary;
-  /** Horizontal location (in pixels) of the monitor. */
-  int x;
-  /** Vertical location  (in pixels) of the monitor. */
-  int y;
-  /** Width of the monitor. */
-  int w;
-  /** Height of the monitor */
-  int h;
-  int mw, mh;
-  /** Output name of the monitor, e.g. eDP1 or VGA-1 */
-  char *name;
-  /** Pointer to next monitor */
-  struct _workarea *next;
-} workarea;
-
-/**
- * @param mon workarea to be filled in.
- *
- * Fills in #mon with the information about the monitor rofi should show on.
- *
- * @returns TRUE if monitor is found, FALSE if no monitor could be detected.
- */
-int monitor_active(workarea *mon);
-
-/**
- * @param w rofis window
- *
- * Stores old input focus for reverting and set focus to rofi.
- */
-void rofi_xcb_set_input_focus(xcb_window_t w);
-
-/**
- * IF set, revert the focus back to the original applications.
- */
-void rofi_xcb_revert_input_focus(void);
-
 /**
  * Depth of visual
  */
