@@ -47,6 +47,7 @@
 
 #include <gio/gio.h>
 
+#include "display.h"
 #include "helper.h"
 #include "history.h"
 #include "mode-private.h"
@@ -56,7 +57,6 @@
 #include "settings.h"
 #include "timings.h"
 #include "widgets/textbox.h"
-#include "xcb.h"
 
 #include "rofi-icon-fetcher.h"
 
@@ -136,6 +136,7 @@ typedef struct {
   /* UID for the icon to display */
   uint32_t icon_fetch_uid;
   uint32_t icon_fetch_size;
+  guint icon_fetch_scale;
   /* Type of desktop file */
   DRunDesktopEntryType type;
 } DRunModeEntry;
@@ -753,6 +754,7 @@ static void read_desktop_file(DRunModePrivateData *pd, const char *root,
   pd->entry_list[pd->cmd_list_length].icon_size = 0;
   pd->entry_list[pd->cmd_list_length].icon_fetch_uid = 0;
   pd->entry_list[pd->cmd_list_length].icon_fetch_size = 0;
+  pd->entry_list[pd->cmd_list_length].icon_fetch_scale = 0;
   pd->entry_list[pd->cmd_list_length].root = g_strdup(root);
   pd->entry_list[pd->cmd_list_length].path = g_strdup(path);
   pd->entry_list[pd->cmd_list_length].desktop_id = g_strdup(id);
@@ -1571,18 +1573,21 @@ static char *_get_display_value(const Mode *sw, unsigned int selected_line,
 static cairo_surface_t *_get_icon(const Mode *sw, unsigned int selected_line,
                                   unsigned int height) {
   DRunModePrivateData *pd = (DRunModePrivateData *)mode_get_private_data(sw);
+  const guint scale = display_scale();
   if (pd->file_complete) {
     return pd->completer->_get_icon(pd->completer, selected_line, height);
   }
   g_return_val_if_fail(pd->entry_list != NULL, NULL);
   DRunModeEntry *dr = &(pd->entry_list[selected_line]);
   if (dr->icon_name != NULL) {
-    if (dr->icon_fetch_uid > 0 && dr->icon_fetch_size == height) {
+    if (dr->icon_fetch_uid > 0 && dr->icon_fetch_size == height &&
+        dr->icon_fetch_scale == scale) {
       cairo_surface_t *icon = rofi_icon_fetcher_get(dr->icon_fetch_uid);
       return icon;
     }
     dr->icon_fetch_uid = rofi_icon_fetcher_query(dr->icon_name, height);
     dr->icon_fetch_size = height;
+    dr->icon_fetch_scale = scale;
     cairo_surface_t *icon = rofi_icon_fetcher_get(dr->icon_fetch_uid);
     return icon;
   }
