@@ -29,6 +29,7 @@
 #define G_LOG_DOMAIN "Modes.Script"
 
 #include "modes/script.h"
+#include "display.h"
 #include "helper.h"
 #include "rofi.h"
 #include <assert.h>
@@ -259,6 +260,7 @@ static DmenuScriptEntry *execute_executor(Mode *sw, char *arg,
             retv[(*length)].urgent = FALSE;
             retv[(*length)].icon_fetch_uid = 0;
             retv[(*length)].icon_fetch_size = 0;
+            retv[(*length)].icon_fetch_scale = 0;
             retv[(*length)].nonselectable = FALSE;
             retv[(*length)].permanent = FALSE;
             if (buf_length > 0 && (read_length > (ssize_t)buf_length)) {
@@ -516,16 +518,19 @@ static cairo_surface_t *script_get_icon(const Mode *sw,
                                         unsigned int height) {
   ScriptModePrivateData *pd =
       (ScriptModePrivateData *)mode_get_private_data(sw);
+  const guint scale = display_scale();
   g_return_val_if_fail(pd->cmd_list != NULL, NULL);
   DmenuScriptEntry *dr = &(pd->cmd_list[selected_line]);
   if (dr->icon_name == NULL) {
     return NULL;
   }
-  if (dr->icon_fetch_uid > 0 && dr->icon_fetch_size == height) {
+  if (dr->icon_fetch_uid > 0 && dr->icon_fetch_size == height &&
+      dr->icon_fetch_scale == scale) {
     return rofi_icon_fetcher_get(dr->icon_fetch_uid);
   }
   dr->icon_fetch_uid = rofi_icon_fetcher_query(dr->icon_name, height);
   dr->icon_fetch_size = height;
+  dr->icon_fetch_scale = scale;
   return rofi_icon_fetcher_get(dr->icon_fetch_uid);
 }
 
