@@ -34,6 +34,7 @@
 #include <stdlib.h>
 #include <string.h>
 // GFile stuff.
+#include "display.h"
 #include "helper.h"
 #include "rofi-icon-fetcher.h"
 #include "rofi-types.h"
@@ -49,6 +50,7 @@
  * list of config files we parsed.
  */
 GList *parsed_config_files = NULL;
+static disp_scale_func disp_scale = NULL;
 
 /** cleanup (free) the list of parsed config files. */
 void rofi_theme_free_parsed_files(void) {
@@ -1070,6 +1072,7 @@ void rofi_theme_get_color(const widget *wid, const char *property, cairo_t *d) {
 
 static gboolean rofi_theme_get_image_inside(Property *p, const widget *wid,
                                             const char *property, cairo_t *d) {
+  const guint scale = disp_scale ? disp_scale() : 1;
   if (p) {
     if (p->type == P_INHERIT) {
       if (wid->parent) {
@@ -1099,17 +1102,15 @@ static gboolean rofi_theme_get_image_inside(Property *p, const widget *wid,
       default:
         break;
       }
-      if (p->value.image.surface_id == 0 || p->value.image.wsize != wsize ||
-          p->value.image.hsize != hsize) {
-        p->value.image.surface_id =
-            rofi_icon_fetcher_query_advanced(p->value.image.url, wsize, hsize);
-        p->value.image.wsize = wsize;
-        p->value.image.hsize = hsize;
-      }
+      // FIXME: cache when hsize, wsize and scale do not change without
+      // modifying RofiImage (for ABI compatibility)
+      p->value.image.surface_id =
+          rofi_icon_fetcher_query_advanced(p->value.image.url, wsize, hsize);
       cairo_surface_t *img = rofi_icon_fetcher_get(p->value.image.surface_id);
 
       if (img != NULL) {
         cairo_pattern_t *pat = cairo_pattern_create_for_surface(img);
+        cairo_surface_set_device_scale(img, scale, scale);
         cairo_pattern_set_extend(pat, CAIRO_EXTEND_REPEAT);
         cairo_set_source(d, pat);
         cairo_pattern_destroy(pat);
@@ -1656,3 +1657,5 @@ gboolean rofi_theme_has_property(const widget *wid_in, const char *property) {
   Property *p = rofi_theme_find_property(wid, P_STRING, property, FALSE);
   return rofi_theme_has_property_inside(p, wid_in, property);
 }
+
+void rofi_theme_set_disp_scale_func(disp_scale_func func) { disp_scale = func; }
