@@ -33,15 +33,12 @@
 #include "theme.h"
 #include "widgets/textbox.h"
 #include "widgets/widget-internal.h"
-#include "xcb-internal.h"
-#include "xcb.h"
 #include <assert.h>
 #include <glib.h>
 #include <helper.h>
 #include <locale.h>
 #include <stdio.h>
 #include <string.h>
-#include <xcb/xcb_ewmh.h>
 
 #include <check.h>
 
